@@ -30,7 +30,7 @@ extern "C" {
 #endif
 
 /**
- * \defgroup pw_keys PipeWire Keys
+ * \defgroup pw_keys Key Names
  *
  * A collection of keys that are used to add extra information on objects.
  *
@@ -61,12 +61,23 @@ extern "C" {
 #define PW_KEY_LIBRARY_NAME_LOOP	"library.name.loop"	/**< name of the loop library to use */
 #define PW_KEY_LIBRARY_NAME_DBUS	"library.name.dbus"	/**< name of the dbus library to use */
 
+/** object properties */
 #define PW_KEY_OBJECT_PATH		"object.path"		/**< unique path to construct the object */
 #define PW_KEY_OBJECT_ID		"object.id"		/**< a global object id */
+#define PW_KEY_OBJECT_SERIAL		"object.serial"		/**< a 64 bit object serial number. This is a number
+								  *  incremented for each object that is created.
+								  *  The lower 32 bits are guaranteed to never be
+								  *  SPA_ID_INVALID. */
+#define PW_KEY_OBJECT_LINGER		"object.linger"		/**< the object lives on even after the client
+								  *  that created it has been destroyed */
+#define PW_KEY_OBJECT_REGISTER		"object.register"	/**< If the object should be registered. */
+
 
 /* config */
 #define PW_KEY_CONFIG_PREFIX		"config.prefix"		/**< a config prefix directory */
 #define PW_KEY_CONFIG_NAME		"config.name"		/**< a config file name */
+#define PW_KEY_CONFIG_OVERRIDE_PREFIX	"config.override.prefix"	/**< a config override prefix directory */
+#define PW_KEY_CONFIG_OVERRIDE_NAME	"config.override.name"	/**< a config override file name */
 
 /* context */
 #define PW_KEY_CONTEXT_PROFILE_MODULES	"context.profile.modules"	/**< a context profile for modules, deprecated */
@@ -150,10 +161,28 @@ extern "C" {
 								  *  a fraction. Ex: 128/48000 */
 #define PW_KEY_NODE_MAX_LATENCY		"node.max-latency"	/**< the maximum supported latency of the
 								  *  node as a fraction. Ex: 1024/48000 */
-#define PW_KEY_NODE_DONT_RECONNECT	"node.dont-reconnect"	/**< don't reconnect this node */
+#define PW_KEY_NODE_LOCK_QUANTUM	"node.lock-quantum"	/**< don't change quantum when this node
+								  *  is active */
+#define PW_KEY_NODE_FORCE_QUANTUM	"node.force-quantum"	/**< force a quantum while the node is
+								  *  active */
+#define PW_KEY_NODE_RATE		"node.rate"		/**< the requested rate of the graph as
+								  *  a fraction. Ex: 1/48000 */
+#define PW_KEY_NODE_LOCK_RATE		"node.lock-rate"	/**< don't change rate when this node
+								  *  is active */
+#define PW_KEY_NODE_FORCE_RATE		"node.force-rate"	/**< force a rate while the node is
+								  *  active */
+
+#define PW_KEY_NODE_DONT_RECONNECT	"node.dont-reconnect"	/**< don't reconnect this node. The node is
+								  *  initially linked to node.target or
+								  *  target.object or the default node. If the
+								  *  targets is removed, the node is destroyed */
 #define PW_KEY_NODE_ALWAYS_PROCESS	"node.always-process"	/**< process even when unlinked */
+#define PW_KEY_NODE_WANT_DRIVER		"node.want-driver"	/**< the node wants to be grouped with a driver
+								  *  node in order to schedule the graph. */
 #define PW_KEY_NODE_PAUSE_ON_IDLE	"node.pause-on-idle"	/**< pause the node when idle */
+#define PW_KEY_NODE_SUSPEND_ON_IDLE	"node.suspend-on-idle"	/**< suspend the node when idle */
 #define PW_KEY_NODE_CACHE_PARAMS	"node.cache-params"	/**< cache the node params */
+#define PW_KEY_NODE_TRANSPORT_SYNC	"node.transport.sync"	/**< the node handles transport sync */
 #define PW_KEY_NODE_DRIVER		"node.driver"		/**< node can drive the graph */
 #define PW_KEY_NODE_STREAM		"node.stream"		/**< node is a stream, the server side should
 								  *  add a converter */
@@ -162,6 +191,12 @@ extern "C" {
 #define PW_KEY_NODE_PASSIVE		"node.passive"		/**< indicate that a node wants passive links
 								  *  on output/input/all ports when the value is
 								  *  "out"/"in"/"true" respectively */
+#define PW_KEY_NODE_LINK_GROUP		"node.link-group"	/**< the node is internally linked to
+								  *  nodes with the same link-group */
+#define PW_KEY_NODE_NETWORK		"node.network"		/**< the node is on a network */
+#define PW_KEY_NODE_TRIGGER		"node.trigger"		/**< the node is not scheduled automatically
+								  *   based on the dependencies in the graph
+								  *   but it will be triggered explicitly. */
 
 /** Port keys */
 #define PW_KEY_PORT_ID			"port.id"		/**< port id */
@@ -219,6 +254,7 @@ extern "C" {
 								  *  "isa", "pci", "usb", "firewire",
 								  *  "bluetooth" */
 #define PW_KEY_DEVICE_SUBSYSTEM		"device.subsystem"	/**< device subsystem */
+#define PW_KEY_DEVICE_SYSFS_PATH	"device.sysfs.path"	/**< device sysfs path */
 #define PW_KEY_DEVICE_ICON		"device.icon"		/**< icon for the device. A base64 blob
 								  *  containing PNG image data */
 #define PW_KEY_DEVICE_ICON_NAME		"device.icon-name"	/**< an XDG icon name for the device.
@@ -257,10 +293,6 @@ extern "C" {
 #define PW_KEY_STREAM_CAPTURE_SINK	"stream.capture.sink"	/**< Try to capture the sink output instead of
 								  *  source output */
 
-/** object properties */
-#define PW_KEY_OBJECT_LINGER		"object.linger"		/**< the object lives on even after the client
-								  *  that created it has been destroyed */
-
 /** Media */
 #define PW_KEY_MEDIA_TYPE		"media.type"		/**< Media type, one of
 								  *  Audio, Video, Midi */
@@ -291,9 +323,11 @@ extern "C" {
 								  *  Ex: "32 bit float mono audio" */
 /** audio related properties */
 #define PW_KEY_AUDIO_CHANNEL		"audio.channel"		/**< an audio channel. Ex: "FL" */
-#define PW_KEY_AUDIO_RATE		"audio.samplerate"	/**< an audio samplerate */
+#define PW_KEY_AUDIO_RATE		"audio.rate"		/**< an audio samplerate */
 #define PW_KEY_AUDIO_CHANNELS		"audio.channels"	/**< number of audio channels */
 #define PW_KEY_AUDIO_FORMAT		"audio.format"		/**< an audio format. Ex: "S16LE" */
+#define PW_KEY_AUDIO_ALLOWED_RATES	"audio.allowed-rates"	/**< a list of allowed samplerates
+								  *  ex. "[ 44100 48000 ]" */
 
 /** video related properties */
 #define PW_KEY_VIDEO_RATE		"video.framerate"	/**< a video framerate */
@@ -304,6 +338,8 @@ extern "C" {
 #define PW_KEY_PRIORITY_MASTER		"priority.master"	/**< deprecated */
 #endif /* PW_ENABLE_DEPRECATED */
 
+#define PW_KEY_TARGET_OBJECT		"target.object"		/**< a target object to link to */
+
 /** \}
  */
 
